@@ -86,8 +86,8 @@ GList *
 biji_get_notes_with_strings (BijibenShellSearchProviderApp *self, gchar **needles)
 {
   gint parser;
-  GString *match = g_string_new ("");
-  gchar *query;
+  GString *match;
+  gchar *query, *needle;
   TrackerSparqlCursor *cursor;
   const gchar *uuid;
   GList *result = NULL;
@@ -95,6 +95,8 @@ biji_get_notes_with_strings (BijibenShellSearchProviderApp *self, gchar **needle
   if (!needles)
     return result;
 
+  match = g_string_new ("");
+
   /* AND is implicit into tracker */
   for (parser=0; needles[parser] != NULL; parser++)
   {
@@ -102,7 +104,18 @@ biji_get_notes_with_strings (BijibenShellSearchProviderApp *self, gchar **needle
     match = g_string_append (match, "* ");
   }
 
-  query = g_strdup_printf ("SELECT ?f WHERE { ?f a nfo:Note ; fts:match '%s' }", match->str);
+  needle = g_utf8_strdown (match->str, -1);
+
+  query = g_strconcat (
+       "SELECT ?urn WHERE {           ",
+       "?urn a nfo:Note;              ",
+       "nie:title ?title ;            ",
+       "nie:plainTextContent ?content ",
+       ". FILTER (fn:contains (fn:lower-case (?content),",
+       "'", needle, "' ) ||            ",
+       "fn:contains (fn:lower-case (?title), '", needle ,"'  ))}",
+       NULL);
+
   g_string_free (match, TRUE);
 
   /* Go to the query */
@@ -122,10 +135,9 @@ tracker_sparql_cursor_next_async    (TrackerSparqlCursor *self,
   {
     uuid = tracker_sparql_cursor_get_string (cursor, 0, 0);
 
-    /* currently no mimetype pushed to tracker by libbiji "push note" method
-     * it shall be added instead testing suffix here */
-    if (uuid && g_str_has_suffix (uuid, ".note"))
+    if (uuid)
       result = g_list_append (result, g_strdup(uuid));
+
   }
 
   g_free (query);
@@ -188,26 +200,37 @@ handle_get_subsearch_result_set (BijibenShellSearchProvider2  *skeleton,
 static gchar *
 get_note_icon (const gchar *note__nie_url)
 {
-  gchar *path, *hash;
+  gchar **split;
+  gchar *path, *basename, *hash;
   GFile *file;
   GIcon *gicon;
 
 
   /*
-   *      we should have a thumbnail
+   *      FIXME - below is ok for local notes only
    * 
-   * URL  :  file://DATA_DIR/bijiben/bf74f3b4-9363-44a1-852a-5746f3118ea7.note
+   * URL  :  DATA_DIR/bijiben/bf74f3b4-9363-44a1-852a-5746f3118ea7.note
+   * URL  :  davs://..../Notes/Trial.txt
+   *
    * ICON :  CACHE_DIR/bijiben/bf74f3b4-9363-44a1-852a-5746f3118ea7.png
+   * ICON :  CACHE_DIR/bijiben/Trial.png
    */
+  split = g_strsplit (note__nie_url, "/", 20);
+
+  basename = biji_str_mass_replace (split [g_strv_length (split)-1],
+                                    ".note",
+                                    ".png",
+                                    ".txt",
+                                    ".png",
+                                    NULL);
+
+  path = g_build_filename (g_get_user_cache_dir (),
+                           "bijiben",
+                           basename,
+                           NULL);
+
+
 
-  path = biji_str_mass_replace (note__nie_url,
-                                "file://",
-                                "",
-                                g_get_user_data_dir (),
-                                g_get_user_cache_dir (),
-                                ".note",
-                                ".png",
-                                NULL);
   file = g_file_new_for_path (path);
 
   if (g_file_query_exists (file, NULL))
@@ -223,8 +246,8 @@ get_note_icon (const gchar *note__nie_url)
                            "48x48", "actions", "note.png", NULL);
   file = g_file_new_for_path (path);
 
-  out:
-
+out:
+  g_strfreev (split);
   gicon = g_file_icon_new (file);
   hash = g_icon_to_string (gicon);
   g_free (path);
@@ -244,9 +267,10 @@ add_single_note_meta (BijibenShellSearchProviderApp *self,
   const gchar *result;
   TrackerSparqlCursor *cursor;
 
-  /* the WHERE nie:url query has a single result : the note which we're providing metadata */
   query = g_strdup_printf ("SELECT nie:url(<%s>) nie:title(<%s>) WHERE { }",
                            note__id, note__id);
+
+
   cursor = bjb_perform_query (self, query);
   g_free (query);
 
@@ -262,6 +286,8 @@ add_single_note_meta (BijibenShellSearchProviderApp *self,
     result = tracker_sparql_cursor_get_string (cursor, 1, 0);
     g_variant_builder_add (results, "{sv}", "name", g_variant_new_string (result));
 
+
+
    /* ICON is currently generic icon,        *
     * TODO serialize icons in libbiji        *
     *      or deserialize note here )        */
